@@ -4,6 +4,10 @@
 #ifndef __PANGO_ENUM_TYPES_H__
 #define __PANGO_ENUM_TYPES_H__
 
+#include <glib-object.h>
+
+G_BEGIN_DECLS
+
 /* enumerations from "pango-attributes.h" */
 
 GType pango_attr_type_get_type (void);
@@ -31,6 +35,9 @@ GType pango_weight_get_type (void);
 GType pango_stretch_get_type (void);
 #define PANGO_TYPE_STRETCH (pango_stretch_get_type())
 
+GType pango_font_mask_get_type (void);
+#define PANGO_TYPE_FONT_MASK (pango_font_mask_get_type())
+
 /* enumerations from "pango-layout.h" */
 
 GType pango_alignment_get_type (void);
@@ -39,6 +46,19 @@ GType pango_alignment_get_type (void);
 GType pango_wrap_mode_get_type (void);
 #define PANGO_TYPE_WRAP_MODE (pango_wrap_mode_get_type())
 
+GType pango_ellipsize_mode_get_type (void);
+#define PANGO_TYPE_ELLIPSIZE_MODE (pango_ellipsize_mode_get_type())
+
+/* enumerations from "pango-renderer.h" */
+
+GType pango_render_part_get_type (void);
+#define PANGO_TYPE_RENDER_PART (pango_render_part_get_type())
+
+/* enumerations from "pango-script.h" */
+
+GType pango_script_get_type (void);
+#define PANGO_TYPE_SCRIPT (pango_script_get_type())
+
 /* enumerations from "pango-tabs.h" */
 
 GType pango_tab_align_get_type (void);
@@ -49,6 +69,8 @@ GType pango_tab_align_get_type (void);
 GType pango_direction_get_type (void);
 #define PANGO_TYPE_DIRECTION (pango_direction_get_type())
 
+G_END_DECLS
+
 #endif /* __PANGO_ENUM_TYPES_H__ */
 
 /* Generated data ends here */
